const HAS_BASE64_FILE_SUPPORT = typeof File !== 'undefined' &&
    typeof FileReader !== 'undefined' &&
    typeof FileList !== 'undefined' &&
    typeof Blob !== 'undefined';
export class Converter {
    constructor(supportedTypes, maxFileSizeInBytes) {
        this.HAS_BASE64_FILE_SUPPORT = HAS_BASE64_FILE_SUPPORT;
        this.supportedTypes = supportedTypes;
        this.maxFileSizeInBytes = maxFileSizeInBytes;
    }
    convert(files, fn = (base64src) => { }, errFn = (file) => { }) {
        if (files && files[0]) {
            files.forEach((file) => {
                const mimeType = file.type;
                if (file.size > this.maxFileSizeInBytes ||
                    !this.supportedTypes.some((fileType) => mimeType.indexOf(fileType) !== -1)) {
                    errFn(file);
                }
                const reader = new FileReader();
                reader.onload = (
                    // tslint:disable-next-line
                    readerEvt) => {
                    const binarySrc = btoa(readerEvt.target.result);
                    fn(`data:${mimeType};base64,${binarySrc}`);
                };
                reader.readAsBinaryString(file);
            });
        }
    }
}
export function dropHandler(converter, e, fn) {
    if (!converter.HAS_BASE64_FILE_SUPPORT ||
        !(e.dataTransfer &&
            e.dataTransfer.files &&
            e.dataTransfer.files.length)) {
        return false;
    }
    const files = Array.prototype.slice.call(e.dataTransfer.files);
    converter.convert(files, (src) => fn({ src }));
    return true;
}
;
export function pasteHandler(converter, e, fn) {
    if (!converter.HAS_BASE64_FILE_SUPPORT ||
        !(e.clipboardData &&
            e.clipboardData.items &&
            e.clipboardData.items.length)) {
        return false;
    }
    const items = e.clipboardData.items;
    const files = (Array.prototype.slice.call(items)).reduce((filesArr, item) => {
        if (item.kind === 'file') {
            filesArr.push(item.getAsFile());
        }
        return filesArr;
    }, []);
    if (files.length) {
        converter.convert(files, (src) => fn({ src }));
        return true;
    }
    return false;
}
//# sourceMappingURL=base64fileconverter.js.map