import { ProseMirror } from 'ak-editor-prosemirror';
import SyncPlugin from './sync-plugin';
import schema from 'ak-editor-schema';
/**
 * Build a ProseMirror instance.
 *
 * Initial selection can be indicated using refs:
 *
 * - `<>` -- a collapsed text selection
 * - `<` and `>` -- a range text selection (`<` is from, `>` is to).
 */
export default (options) => {
    const pm = new ProseMirror({
        doc: options.doc,
        place: options.place,
        schema: options.schema || schema,
        plugins: [
            options.plugin,
            SyncPlugin,
        ]
    });
    const { refs } = pm.doc;
    // Collapsed selection.
    if ('<>' in refs) {
        pm.setTextSelection(refs['<>']);
    }
    else if ('<' in refs || '>' in refs) {
        if ('<' in refs === false)
            throw new Error('A `<` ref must complement a `>` ref.');
        if ('>' in refs === false)
            throw new Error('A `>` ref must complement a `<` ref.');
        pm.setTextSelection(refs['<'], refs['>']);
    }
    return { pm, plugin: options.plugin.get(pm) };
};
//# sourceMappingURL=make-editor.js.map