import { Plugin } from 'ak-editor-prosemirror';
export class SyncPlugin {
    constructor(pm) {
        // Poke inside the trigger all update schedulers. Normally it would be
        // done on a timeout if the editor is in the DOM, but for tests we want to
        // skip that requirement.
        function forceSync() {
            pm.centralScheduler.force();
        }
        // Some subscription handlers need to adhere to specific behaviour (e.g.
        // returning a value).
        const handlers = {
            transformPasted(slice) {
                forceSync();
                return slice;
            },
            transformPastedText(text) {
                forceSync();
                return text;
            },
            transformPastedHTML(html) {
                forceSync();
                return html;
            },
        };
        const defaultHandler = () => { forceSync(); };
        Object.keys(pm.on)
            .forEach(name => {
            const handler = handlers[name] || defaultHandler;
            pm.on[name].add(handler);
        });
    }
}
;
export default new Plugin(SyncPlugin);
//# sourceMappingURL=sync-plugin.js.map