"use strict";
var HAS_BASE64_FILE_SUPPORT = typeof File !== 'undefined' &&
    typeof FileReader !== 'undefined' &&
    typeof FileList !== 'undefined' &&
    typeof Blob !== 'undefined';
var Converter = (function () {
    function Converter(supportedTypes, maxFileSizeInBytes) {
        this.HAS_BASE64_FILE_SUPPORT = HAS_BASE64_FILE_SUPPORT;
        this.supportedTypes = supportedTypes;
        this.maxFileSizeInBytes = maxFileSizeInBytes;
    }
    Converter.prototype.convert = function (files, fn, errFn) {
        var _this = this;
        if (fn === void 0) { fn = function (base64src) { }; }
        if (errFn === void 0) { errFn = function (file) { }; }
        if (files && files[0]) {
            files.forEach(function (file) {
                var mimeType = file.type;
                if (file.size > _this.maxFileSizeInBytes ||
                    !_this.supportedTypes.some(function (fileType) { return mimeType.indexOf(fileType) !== -1; })) {
                    errFn(file);
                }
                var reader = new FileReader();
                reader.onload = function (
                    // tslint:disable-next-line
                    readerEvt) {
                    var binarySrc = btoa(readerEvt.target.result);
                    fn("data:" + mimeType + ";base64," + binarySrc);
                };
                reader.readAsBinaryString(file);
            });
        }
    };
    return Converter;
}());
exports.Converter = Converter;
function dropHandler(converter, e, fn) {
    if (!converter.HAS_BASE64_FILE_SUPPORT ||
        !(e.dataTransfer &&
            e.dataTransfer.files &&
            e.dataTransfer.files.length)) {
        return false;
    }
    var files = Array.prototype.slice.call(e.dataTransfer.files);
    converter.convert(files, function (src) { return fn({ src: src }); });
    return true;
}
exports.dropHandler = dropHandler;
;
function pasteHandler(converter, e, fn) {
    if (!converter.HAS_BASE64_FILE_SUPPORT ||
        !(e.clipboardData &&
            e.clipboardData.items &&
            e.clipboardData.items.length)) {
        return false;
    }
    var items = e.clipboardData.items;
    var files = (Array.prototype.slice.call(items)).reduce(function (filesArr, item) {
        if (item.kind === 'file') {
            filesArr.push(item.getAsFile());
        }
        return filesArr;
    }, []);
    if (files.length) {
        converter.convert(files, function (src) { return fn({ src: src }); });
        return true;
    }
    return false;
}
exports.pasteHandler = pasteHandler;
//# sourceMappingURL=base64fileconverter.js.map