"use strict";
var create_event_1 = require("./create-event");
function focusAndSelect(element) {
    var range = document.createRange();
    var selection = window.getSelection();
    range.selectNodeContents(element);
    selection.removeAllRanges();
    selection.addRange(range);
    element.focus();
}
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Dispatch a paste event on the given ProseMirror instance
 *
 * Usage:
 *     dispatchPasteEvent(pm, {
 *         plain: 'copied text'
 *     });
 */
exports.default = function (pm, content) {
    var event = create_event_1.default('paste');
    var clipboardData = {
        getData: function (type) {
            if (type === 'text/plain') {
                return content.plain;
            }
            if (type === 'text/html') {
                return content.html;
            }
        },
        types: [],
    };
    try {
        Object.defineProperty(event, 'clipboardData', { value: clipboardData });
    }
    catch (e) {
        // iOS 9 will throw if we assign `clipboardData` to `event`
        // revert this change once iOS 10 is out
        return false;
    }
    // ProseMirror must be focused, else it does not attempt to handle pasted content.
    focusAndSelect(pm.content);
    pm.content.dispatchEvent(event);
    return true;
};
//# sourceMappingURL=dispatch-paste-event.js.map