"use strict";
var ak_editor_prosemirror_1 = require("ak-editor-prosemirror");
var sync_plugin_1 = require("./sync-plugin");
var ak_editor_schema_1 = require("ak-editor-schema");
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Build a ProseMirror instance.
 *
 * Initial selection can be indicated using refs:
 *
 * - `<>` -- a collapsed text selection
 * - `<` and `>` -- a range text selection (`<` is from, `>` is to).
 */
exports.default = function (options) {
    var pm = new ak_editor_prosemirror_1.ProseMirror({
        doc: options.doc,
        place: options.place,
        schema: options.schema || ak_editor_schema_1.default,
        plugins: [
            options.plugin,
            sync_plugin_1.default,
        ]
    });
    var refs = pm.doc.refs;
    // Collapsed selection.
    if ('<>' in refs) {
        pm.setTextSelection(refs['<>']);
    }
    else if ('<' in refs || '>' in refs) {
        if ('<' in refs === false)
            throw new Error('A `<` ref must complement a `>` ref.');
        if ('>' in refs === false)
            throw new Error('A `>` ref must complement a `<` ref.');
        pm.setTextSelection(refs['<'], refs['>']);
    }
    return { pm: pm, plugin: options.plugin.get(pm) };
};
//# sourceMappingURL=make-editor.js.map