"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Example:
 *
 *     // src/index.js
 *     import browser from 'browser';
 *
 *     export default function assertMac() {
 *        if (!browser.mac) {
 *          throw new Error('Must be a mac');
 *        }
 *     }
 *
 *     // tests/index.js
 *     import module, { assertMac } from '../src';
 *
 *     describe('a suite', () => {
 *       const rewireMock = RewireMock();
 *
 *       it('a test', () => {
 *         const mockBrowser = { mac: false };
 *         rewireMock(module, 'browser', mockBrowser);
 *         expect(assertMac).to.throw(Error);
 *       });
 *     });
 *
 * The `RewireMock` creates a factory function that can be used within tests. It automatically
 * handles resetting the rewired dependency.
 */
exports.default = function () {
    var resetAfter = [];
    afterEach(function () { return resetAfter.map(function (_a) {
        var module = _a.module, name = _a.name;
        return module.__ResetDependency__(name);
    }); });
    return function (module, name, mock) {
        module.__Rewire__(name, mock);
        resetAfter.push({ module: module, name: name });
    };
};
//# sourceMappingURL=rewire-mock.js.map